==> hydroserver_sensorthings-0.1.11-py3-none-any.whl: sensorthings/components/datastreams/views.py <==
from ninja import Router, Query
from django.http import HttpResponse
from sensorthings.engine import SensorThingsRequest
from sensorthings.schemas import ListQueryParams, GetQueryParams
from sensorthings.utils import entities_or_404, entity_or_404, generate_response_codes, parse_query_params
from .schemas import DatastreamPostBody, DatastreamPatchBody, DatastreamListResponse, DatastreamGetResponse


router = Router(tags=['Datastreams'])


@router.get(
    '/Datastreams',
    response=generate_response_codes('list', DatastreamListResponse),
    by_alias=True,
    exclude_unset=True,
    url_name='list_datastream'
)
def list_datastreams(request: SensorThingsRequest, params: ListQueryParams = Query(...)):
    """
    Get a collection of Datastream entities.

    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/properties" target="_blank">\
      Datastream Properties</a> -
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/relations" target="_blank">\
      Datastream Relations</a>
    """

    response = request.engine.list(
        **parse_query_params(
            query_params=params.dict(),
            entity_chain=request.entity_chain
        )
    )

    return entities_or_404(response, DatastreamListResponse)


@router.get(
    '/Datastreams({datastream_id})',
    response=generate_response_codes('get', DatastreamGetResponse),
    by_alias=True,
    exclude_unset=True
)
def get_datastream(request: SensorThingsRequest, datastream_id: str, params: GetQueryParams = Query(...)):
    """
    Get a Datastream entity.

    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/properties" target="_blank">\
      Datastream Properties</a> -
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/relations" target="_blank">\
      Datastream Relations</a>
    """

    response = request.engine.get(
        entity_id=datastream_id,
        **parse_query_params(
            query_params=params.dict()
        )
    )

    return entity_or_404(response, datastream_id, DatastreamGetResponse)


@router.post(
    '/Datastreams',
    response=generate_response_codes('create')
)
def create_datastream(request: SensorThingsRequest, response: HttpResponse, datastream: DatastreamPostBody):
    """
    Create a new Datastream entity.

    Links:
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/properties" target="_blank">\
      Datastream Properties</a> -
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/relations" target="_blank">\
      Datastream Relations</a> -
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/create-update-delete/create-entity" target="_blank">\
      Create Entity</a>
    """

    datastream_id = request.engine.create(
        entity_body=datastream
    )

    response['location'] = request.engine.get_ref(
        entity_id=datastream_id
    )

    return 201, None


@router.patch(
    '/Datastreams({datastream_id})',
    response=generate_response_codes('update')
)
def update_datastream(request: SensorThingsRequest, datastream_id: str, datastream: DatastreamPatchBody):
    """
    Update an existing Datastream entity.

    Links:
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/properties" target="_blank">\
      Datastream Properties</a> -
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/relations" target="_blank">\
      Datastream Relations</a> -
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/create-update-delete/update-entity" target="_blank">\
      Update Entity</a>
    """

    request.engine.update(
        entity_id=datastream_id,
        entity_body=datastream
    )

    return 204, None


@router.delete(
    '/Datastreams({datastream_id})',
    response=generate_response_codes('delete')
)
def delete_datastream(request: SensorThingsRequest, datastream_id: str):
    """
    Delete a Datastream entity.

    Links:
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/create-update-delete/delete-entity" target="_blank">\
      Delete Entity</a>
    """

    request.engine.delete(
        entity_id=datastream_id
    )

    return 204, None

==> hydroserver_sensorthings-0.2.0-py3-none-any.whl: sensorthings/components/datastreams/views.py <==
from ninja import Query
from sensorthings.router import SensorThingsRouter
from sensorthings.engine import SensorThingsRequest
from sensorthings.schemas import ListQueryParams, GetQueryParams
from .schemas import DatastreamPostBody, DatastreamPatchBody, DatastreamListResponse, DatastreamGetResponse


router = SensorThingsRouter(tags=['Datastreams'])


@router.st_get('/Datastreams', response_schema=DatastreamListResponse, url_name='list_datastream')
def list_datastreams(
        request: SensorThingsRequest,
        params: ListQueryParams = Query(...)
):
    """
    Get a collection of Datastream entities.

    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/properties" target="_blank">\
      Datastream Properties</a> -
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/relations" target="_blank">\
      Datastream Relations</a>
    """

    return request.engine.list_entities(
        request=request,
        query_params=params.dict()
    )


@router.st_get('/Datastreams({datastream_id})', response_schema=DatastreamGetResponse)
def get_datastream(
        request: SensorThingsRequest,
        datastream_id: str,
        params: GetQueryParams = Query(...)
):
    """
    Get a Datastream entity.

    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/properties" target="_blank">\
      Datastream Properties</a> -
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/relations" target="_blank">\
      Datastream Relations</a>
    """

    return request.engine.get_entity(
        request=request,
        entity_id=datastream_id,
        query_params=params.dict()
    )


@router.st_post('/Datastreams')
def create_datastream(
        request: SensorThingsRequest,
        datastream: DatastreamPostBody
):
    """
    Create a new Datastream entity.

    Links:
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/properties" target="_blank">\
      Datastream Properties</a> -
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/relations" target="_blank">\
      Datastream Relations</a> -
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/create-update-delete/create-entity" target="_blank">\
      Create Entity</a>
    """

    return request.engine.create_entity(
        request=request,
        entity_body=datastream
    )


@router.patch('/Datastreams({datastream_id})')
def update_datastream(
        request: SensorThingsRequest,
        datastream_id: str,
        datastream: DatastreamPatchBody
):
    """
    Update an existing Datastream entity.

    Links:
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/properties" target="_blank">\
      Datastream Properties</a> -
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/datamodel/datastream/relations" target="_blank">\
      Datastream Relations</a> -
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/create-update-delete/update-entity" target="_blank">\
      Update Entity</a>
    """

    return request.engine.update_entity(
        request=request,
        entity_id=datastream_id,
        entity_body=datastream
    )


@router.delete('/Datastreams({datastream_id})')
def delete_datastream(
        request: SensorThingsRequest,
        datastream_id: str
):
    """
    Delete a Datastream entity.

    Links:
    <a href="http://www.opengis.net/spec/iot_sensing/1.1/req/create-update-delete/delete-entity" target="_blank">\
      Delete Entity</a>
    """

    return request.engine.delete_entity(
        request=request,
        entity_id=datastream_id
    )
